@@ -300,13 +300,17 @@ adjmat_to_edgelist <- function(
   keep.isolates = getOption("diffnet.keep.isolates", TRUE)
   ) {
 
-  out <- switch (class(graph),
-          list      = adjmat_to_edgelist.list(graph, undirected, keep.isolates),
-          array     = adjmat_to_edgelist.array(graph, undirected, keep.isolates),
-          dgCMatrix = cbind(adjmat_to_edgelist.dgCMatrix(graph, undirected, keep.isolates), 1),
-          matrix    = cbind(adjmat_to_edgelist.matrix(graph, undirected, keep.isolates),1),
-          stopifnot_graph(graph)
-  )
+  cls <- class(graph)
+  out <- if ("list" %in% cls) {
+      adjmat_to_edgelist.list(graph, undirected, keep.isolates)
+    } else if ("matrix" %in% cls) {
+      cbind(adjmat_to_edgelist.matrix(graph, undirected, keep.isolates),1)
+    } else if ("array" %in% cls) {
+      adjmat_to_edgelist.array(graph, undirected, keep.isolates)
+    } else if ("dgCMatrix" %in% cls) {
+      cbind(adjmat_to_edgelist.dgCMatrix(graph, undirected, keep.isolates), 1)
+    } else
+      stopifnot_graph(graph)
 
   colnames(out) <- c("ego", "alter", "value", "time")
   out
@@ -465,12 +469,16 @@ toa_mat <- function(obj, labels=NULL, t0=NULL, t1=NULL) {
     if (!length(t1)) t1 <- max(obj, na.rm = TRUE)
   }
 
-  ans <- switch(class(obj),
-    numeric = toa_mat.numeric(obj, labels, t0, t1),
-    integer = toa_mat.integer(obj, labels, t0, t1),
-    diffnet = with(obj, list(adopt=adopt,cumadopt=cumadopt)),
-    stopifnot_graph(obj)
-  )
+  cls <- class(obj)
+  ans <- if ("numeric" %in% cls) {
+    toa_mat.numeric(obj, labels, t0, t1)
+    } else if ("integer" %in% cls) {
+    toa_mat.integer(obj, labels, t0, t1)
+    } else if  ("diffnet" %in% cls) {
+    with(obj, list(adopt=adopt,cumadopt=cumadopt))
+    } else
+      stopifnot_graph(obj)
+
 
   if (inherits(obj, "diffnet")) {
     dimnames(ans$adopt) <- with(obj$meta, list(ids,pers))
@@ -658,15 +666,20 @@ isolated <- function(
   undirected = getOption("diffnet.undirected", FALSE),
   self = getOption("diffnet.self", FALSE)
 ) {
-  ans <- switch (class(graph),
-    matrix    = isolated.default(methods::as(graph, "dgCMatrix"), undirected, self),
-    dgCMatrix = isolated.default(graph, undirected, self),
-    array     = lapply(apply(graph, 3, methods::as, Class="dgCMatrix"), isolated.default,
-                       undirected=undirected, self=self),
-    list      = lapply(graph, isolated.default, undirected=undirected, self=self),
-    diffnet   = lapply(graph$graph, isolated.default, undirected=undirected, self=self),
-    stopifnot_graph(graph)
-  )
+  cls <- class(graph)
+  ans <- if ("matrix" %in% cls) {
+      isolated.default(methods::as(graph, "dgCMatrix"), undirected, self)
+    } else if ("dgCMatrix" %in% cls) {
+      isolated.default(graph, undirected, self)
+    } else if ("array" %in% cls) {
+      lapply(apply(graph, 3, methods::as, Class="dgCMatrix"), isolated.default,
+                       undirected=undirected, self=self)
+    } else if ("list" %in% cls) {
+      lapply(graph, isolated.default, undirected=undirected, self=self)
+    } else if ("diffnet" %in% cls) {
+      lapply(graph$graph, isolated.default, undirected=undirected, self=self)
+    } else
+      stopifnot_graph(graph)
 
   if (any(class(graph) %in% c("list", "diffnet", "array")))
     apply(do.call(cbind, ans), 1, all)
